====
boknows
====

Get NCAA stats and figures without the hassle of stats.ncaa.org

* Documentation: http://boknows.readthedocs.org/
* Repository: https://github.com/nbedi/boknows/
* Issues: https://github.com/nbedi/boknows/issues

.. image:: https://travis-ci.org/nbedi/boknows.svg
    :target: https://travis-ci.org/nbedi/boknows
    :alt: Build status
